@@ -42,6 +42,8 @@
 #' @seealso \code{\link{stanreg-methods}}
 #' 
 #' @examples
+#' \dontrun{
+#' if (!exists("example_model")) example(example_model)
 #' # Extract posterior sample after MCMC
 #' draws <- as.matrix(example_model)
 #' 
@@ -50,7 +52,6 @@
 #' print(median(draws[, "(Intercept)"]))
 #' print(example_model$coefficients[["(Intercept)"]])
 #' 
-#' \dontrun{
 #' # Extract draws from asymptotic Gaussian sampling distribution 
 #' # after optimization
 #' fit <- stan_glm(mpg ~ wt, data = mtcars, algorithm = "optimizing")
@@ -85,6 +86,7 @@ as.matrix.stanreg <- function(x, ..., pars = NULL, regex_pars = NULL) {
       STOP_no_draws()
     posterior <- rstan::extract(x$stanfit, permuted = FALSE, inc_warmup = FALSE)
     mat <- apply(posterior, 3L, FUN = function(y) y)
+    if (length(dim(mat)) < 2L) mat <- t(as.matrix(mat))
     if (!user_pars)
       pars <- grep("mean_PPD|log-posterior", # exclude these by default
                    colnames(mat), invert = TRUE, value = TRUE)
