@@ -24,7 +24,7 @@
 #' the fit of the model. Drawing from the posterior predictive distribution at 
 #' interesting values of the predictors also lets us visualize how a 
 #' manipulation of a predictor affects (a function of) the outcome(s). With new 
-#' observations of predictor variables we can use posterior predictive 
+#' observations of predictor variables we can use the posterior predictive 
 #' distribution to generate predicted outcomes.
 #' 
 #' @export
@@ -81,6 +81,7 @@
 #'   \pkg{rstanarm} vignettes and demos.
 #'   
 #' @examples
+#' if (!exists("example_model")) example(example_model)
 #' yrep <- posterior_predict(example_model)
 #' table(yrep)
 #' 
@@ -123,8 +124,7 @@
 #' 
 posterior_predict <- function(object, newdata = NULL, draws = NULL, 
                               re.form = NULL, fun = NULL, seed = NULL, ...) {
-  if (!is.stanreg(object))
-    stop(deparse(substitute(object)), " is not a stanreg object.")
+  validate_stanreg_object(object)
   if (used.optimizing(object))
     STOP_not_optimizing("posterior_predict")
   if (!is.null(seed)) 
@@ -140,7 +140,23 @@ posterior_predict <- function(object, newdata = NULL, draws = NULL,
       stop("Currently NAs are not allowed in 'newdata'.")
   }
   dat <- pp_data(object, newdata, re.form, ...)
-  ppargs <- pp_args(object, data = pp_eta(object, dat, draws))
+  if (is_scobit(object)) {
+    data <- pp_eta(object, dat, NULL)
+    if (!is.null(draws)) {
+      S <- posterior_sample_size(object)
+      if (draws > S) {
+        err <- paste0("'draws' should be <= posterior sample size (", 
+                      S, ").")
+        stop(err)
+      }
+      samp <- sample(S, draws)
+      data$eta <- data$eta[samp, , drop = FALSE]
+      ppargs <- pp_args(object, data)
+      ppargs$alpha <- ppargs$alpha[samp]
+    }
+    else ppargs <- pp_args(object, data)
+  }
+  else ppargs <- pp_args(object, data = pp_eta(object, dat, draws))
   if (!is(object, "polr") && is.binomial(family(object)$family))
     ppargs$trials <- pp_binomial_trials(object, newdata)
   
@@ -150,7 +166,8 @@ posterior_predict <- function(object, newdata = NULL, draws = NULL,
     ytilde <- t(ytilde)
   if (!is.null(fun)) 
     ytilde <- do.call(fun, list(ytilde))
-  
+  if (is(object, "polr") && !is_scobit(object))
+    ytilde <- matrix(levels(get_y(object))[ytilde], nrow(ytilde), ncol(ytilde))
   return(ytilde)
 }
 
@@ -204,13 +221,15 @@ pp_fun <- function(object) {
   n <- ncol(eta)
   q <- ncol(zeta)
   if (!is.null(alpha)) {
-    t(sapply(1:nrow(eta), FUN = function(s) {
-      tmp <- matrix(zeta[s,], n, q, byrow = TRUE) - eta[s, ]
-      pr <- matrix(linkinv(tmp)^alpha, , q)
-      rbinom(ncol(eta), size = 1, prob = pr[s, ])
+    pr <- linkinv(eta)^alpha
+    if (NROW(eta) == 1) {
+      pr <- matrix(pr, nrow = 1)  
+    }
+    t(sapply(1:NROW(eta), FUN = function(s) {
+      rbinom(NCOL(eta), size = 1, prob = pr[s, ])
     }))
   } else {
-    t(sapply(1:nrow(eta), FUN = function(s) {
+    t(sapply(1:NROW(eta), FUN = function(s) {
       tmp <- matrix(zeta[s, ], n, q, byrow = TRUE) - eta[s, ]
       cumpr <- matrix(linkinv(tmp), , q)
       fitted <- t(apply(cumpr, 1L, function(x) diff(c(0, x, 1))))
@@ -304,14 +323,35 @@ pp_b_ord <- function(b, Z_names) {
       return(m)
     if (len > 1) 
       stop("multiple matches bug")
-    x <- sub(" (.*):.*$", " \\1:_NEW_\\1", x)
-    grep(paste0("b[", x, "]"), colnames(b), fixed = TRUE)
+    m <- grep(paste0("b[", sub(" (.*):.*$", " \\1:_NEW_\\1", x), "]"), 
+              colnames(b), fixed = TRUE)
+    if (len == 1)
+      return(m)
+    if (len > 1)
+      stop("multiple matches bug")
+    x <- strsplit(x, split = ":", fixed = TRUE)[[1]]
+    stem <- strsplit(x[[1]], split = " ", fixed = TRUE)[[1]]
+    x <- paste(x[1], x[2], paste0("_NEW_", stem[2]), x[2], sep = ":")
+    m <- grep(paste0("b[", x, "]"), colnames(b), fixed = TRUE)
+    len <- length(m)
+    if (len == 1)
+      return(m)
+    if (len > 1)
+      stop("multiple matches bug")
+    x <- paste(paste(stem[1], stem[2]), paste0("_NEW_", stem[2]), sep = ":")
+    m <- grep(paste0("b[", x, "]"), colnames(b), fixed = TRUE)
+    len <- length(m)
+    if (len == 1)
+      return(m)
+    if (len > 1)
+      stop("multiple matches bug")
+    stop("no matches bug")    
   })
   b[, ord, drop = FALSE]
 }
 
 # Number of trials for binomial models
-pp_binomial_trials <- function(object, newdata) {
+pp_binomial_trials <- function(object, newdata = NULL) {
   y <- if (is.null(newdata))
     get_y(object) else eval(formula(object)[[2L]], newdata)
   if (NCOL(y) == 2L) 
