@@ -1,5 +1,5 @@
 # Part of the rstanarm package for estimating model parameters
-# Copyright (C) 2013, 2014, 2015 Trustees of Columbia University
+# Copyright (C) 2013, 2014, 2015, 2016 Trustees of Columbia University
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -88,6 +88,11 @@
 #'   calls \code{stan_lm} with dummy variables to do a Bayesian analysis of
 #'   variance.
 #'   
+#'   
+#' @references 
+#' Lewandowski, D., Kurowicka D., and Joe, H. (2009). Generating random
+#' correlation matrices based on vines and extended onion method. 
+#' \emph{Journal of Multivariate Analysis}. \strong{100}(9), 1989--2001.
 #' 
 #' @seealso 
 #' The vignettes for \code{stan_lm} and \code{stan_aov}, which have more
@@ -114,6 +119,7 @@ stan_lm <- function(formula, data, subset, weights, na.action,
                     adapt_delta = NULL) {
   
   algorithm <- match.arg(algorithm)
+  validate_glm_formula(formula)
   call <- match.call(expand.dots = TRUE)
   mf <- match.call(expand.dots = FALSE)
   mf[[1L]] <- as.name("lm")
