@@ -43,18 +43,19 @@ stanreg <- function(object) {
     rank <- qr(x, tol = .Machine$double.eps, LAPACK = TRUE)$rank
     df.residual <- nobs - sum(object$weights == 0) - rank
   } else {
-    levs <- c(0.5, 0.8, 0.95, 0.99)
-    qq <- (1 - levs) / 2
-    probs <- sort(c(0.5, qq, 1 - qq))
-    stan_summary <- rstan::summary(stanfit, probs = probs, digits = 10)$summary
+    stan_summary <- make_stan_summary(stanfit)
     coefs <- stan_summary[1:nvars, select_median(object$algorithm)]
     if (length(coefs) == 1L) # ensures that if only a single coef it still gets a name
       names(coefs) <- rownames(stan_summary)[1L]
-    
+
     stanmat <- as.matrix(stanfit)[, 1:nvars, drop = FALSE]
-    covmat <- cov(stanmat)
-    rownames(covmat) <- colnames(covmat) <- rownames(stan_summary)[1:nvars]
     ses <- apply(stanmat, 2L, mad)
+    if (mer) {
+      mark <- sum(sapply(object$stanfit@par_dims[c("alpha", "beta")], prod))
+      stanmat <- stanmat[,1:mark, drop = FALSE]
+    }
+    covmat <- cov(stanmat)
+    rownames(covmat) <- colnames(covmat) <- rownames(stan_summary)[1:nrow(covmat)]
     if (object$algorithm == "sampling") 
       check_rhats(stan_summary[, "Rhat"])
   }
@@ -73,12 +74,13 @@ stanreg <- function(object) {
   names(eta) <- names(mu) <- names(residuals) <- ynames
   
   out <- nlist(
-    coefficients = coefs, 
-    ses,
+    coefficients = unpad_reTrms(coefs), 
+    ses = unpad_reTrms(ses),
     fitted.values = mu,
     linear.predictors = eta,
     residuals, 
     df.residual = if (opt) df.residual else NA_integer_, 
+    # covmat = unpad_reTrms(unpad_reTrms(covmat, col = TRUE), col = FALSE),
     covmat,
     y, 
     x, 
