@@ -1,9 +1,7 @@
 ## ---- SETTINGS-knitr, include=FALSE--------------------------------------
-stopifnot(require(svglite))
 stopifnot(require(knitr))
 opts_chunk$set(
   comment=NA, message = FALSE, warning = FALSE,
-  dev = 'svglite', fig.ext='svg', fig.path = "SVGs/",
   fig.align='center', fig.width = 7, fig.height = 3
 )
 
@@ -25,11 +23,11 @@ SEED <- 12345
 loo.cores <- if (exists("CORES")) CORES else 1L
 options(loo.cores = loo.cores)
 
-## ----aov-----------------------------------------------------------------
+## ----aov-weightgain-aov--------------------------------------------------
 data("weightgain", package = "HSAUR3")
 coef(aov(weightgain ~ source * type, data = weightgain))
 
-## ----stan_aov, results="hide"--------------------------------------------
+## ----aov-weightgain-mcmc, results="hide"---------------------------------
 library(rstanarm)
 post1 <- stan_aov(weightgain ~ source * type, data = weightgain, 
                   prior = R2(location = 0.5), adapt_delta = 0.999,
@@ -39,7 +37,7 @@ post1
 ## ---- echo=FALSE---------------------------------------------------------
 print(post1)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- aov-weightgain-stan_lmer, eval=FALSE-------------------------------
 #  post2 <- stan_lmer(weightgain ~ 1 + (1|source) + (1|type) + (1|source:type),
 #                     data = weightgain, prior_intercept = cauchy(),
 #                     prior_covariance = decov(shape = 2, scale = 2),
