@@ -207,23 +207,25 @@ test_that("sigma method works", {
   expect_identical(rsigma(stan_polr1), 1)
   expect_identical(rsigma(example_model), 1)
   
-  expect_is(sig <- rsigma(stan_lmer1), "numeric")
+  expect_double <- function(x) expect_type(x, "double")
+  
+  expect_double(sig <- rsigma(stan_lmer1))
   expect_false(identical(sig, 1))
-  expect_is(sig <- rsigma(stan_lmer2), "numeric")
+  expect_double(sig <- rsigma(stan_lmer2))
   expect_false(identical(sig, 1))
-  expect_is(sig <- rsigma(stan_glm1), "numeric")
+  expect_double(sig <- rsigma(stan_glm1))
   expect_false(identical(sig, 1))
-  expect_is(sig <- rsigma(stan_glm_vb1), "numeric")
+  expect_double(sig <- rsigma(stan_glm_vb1))
   expect_false(identical(sig, 1))
-  expect_is(sig <- rsigma(stan_glm_opt1), "numeric")
+  expect_double(sig <- rsigma(stan_glm_opt1))
   expect_false(identical(sig, 1))
 })
 
 test_that("VarCorr returns correct structure", {
   vc_lmer1 <- VarCorr(lmer1); vc_stan1 <- VarCorr(stan_lmer1)
   vc_lmer2 <- VarCorr(lmer2); vc_stan2 <- VarCorr(stan_lmer2)
-  expect_is(vc_stan1, class(vc_lmer1))
-  expect_is(vc_stan2, class(vc_lmer2))
+  expect_s3_class(vc_stan1, class(vc_lmer1))
+  expect_s3_class(vc_stan2, class(vc_lmer2))
   check_att_names(vc_stan1, vc_lmer1)
   check_att_names(vc_stan2, vc_lmer2)
   expect_error(VarCorr(stan_glm1), "stan_glmer and stan_lmer models only")
@@ -232,8 +234,8 @@ test_that("VarCorr returns correct structure", {
 test_that("ranef returns correct structure", {
   re_stan1 <- ranef(stan_lmer1); re_lmer1 <- ranef(lmer1)
   re_stan2 <- ranef(stan_lmer1); re_lmer2 <- ranef(lmer1)
-  expect_is(re_stan1, class(re_lmer1))
-  expect_is(re_stan2, class(re_lmer2))
+  expect_s3_class(re_stan1, class(re_lmer1))
+  expect_s3_class(re_stan2, class(re_lmer2))
   check_att_names(re_stan1, re_lmer1)
   check_att_names(re_stan2, re_lmer2)
   check_sizes(re_stan1, re_lmer1)
@@ -362,7 +364,7 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_identical(s, s_alt)
   expect_silent(s <- summary(stan_lmer1))
   expect_silent(d <- as.data.frame(s))
-  expect_is(s, "summary.stanreg")
+  expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_lmer")
   expect_identical(attr(s, "algorithm"), "sampling")
   expect_identical(colnames(s), colnames(d))
@@ -372,7 +374,7 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_silent(s_alt <- summary(example_model, pars = c("beta", "varying")))
   expect_identical(s, s_alt)
   expect_silent(d <- as.data.frame(s))
-  expect_is(s, "summary.stanreg")
+  expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_glmer")
   expect_output(print(s), paste("Posterior sample size:",  
                                 rstanarm:::posterior_sample_size(example_model)))
@@ -386,19 +388,19 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_identical(rownames(s), c("agegp.L", "agegp.Q", "agegp.C", "agegp^4", "agegp^5"))
   expect_identical(colnames(s), colnames(d))
   expect_identical(rownames(s), rownames(d))
-  expect_is(s, "summary.stanreg")
+  expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_polr")
   
   expect_warning(s <- summary(stan_glm1, pars = "varying"), 
                  regexp = "No group-specific parameters. 'varying' ignored.")
   expect_silent(s <- summary(stan_glm1, pars = c("alpha", "beta"), digits = 3))
-  expect_is(s, "summary.stanreg")
+  expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_glm")
   expect_identical(attr(s, "algorithm"), "sampling")
   
   expect_silent(s <- summary(stan_glm_vb1, pars = c("alpha", "beta")))
   expect_silent(d <- as.data.frame(s))
-  expect_is(s, "summary.stanreg")
+  expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_glm")
   expect_identical(attr(s, "algorithm"), "meanfield")
 })
@@ -409,7 +411,7 @@ test_that("print and summary methods ok for optimization", {
   expect_warning(s <- summary(stan_glm_opt1, regex_pars = c("wt", "sigma")), 
                  regexp = "'regex_pars' ignored")
   expect_silent(d <- as.data.frame(s))
-  expect_is(s, "summary.stanreg")
+  expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_glm")
   expect_identical(attr(s, "algorithm"), "optimizing")
   expect_identical(colnames(s), colnames(d))
@@ -506,9 +508,9 @@ test_that("update works properly", {
   expect_is(call_only, "call")
   expect_identical(call_only, getCall(fit))
   
-  expect_warning(fit <- update(fit, algorithm = "optimizing"), 
-                 regexp = "unknown arguments: chains")
-  expect_identical(fit$algorithm, "optimizing")
+  expect_error(fit <- update(fit, algorithm = "optimizing"), 
+               regexp = "unknown arguments: chains")
+  expect_identical(fit$algorithm, "sampling")
   
   fit$call <- NULL
   expect_error(update(fit), regexp = "does not contain a 'call' component")
