@@ -25,11 +25,15 @@ ITER <- 400
 threshold <- 0.21
 REFRESH <- 0
 
+expect_stanreg <- function(x) expect_s3_class(x, "stanreg")
+
 context("stan_lm")
 test_that("stan_lm returns expected result for mtcars example", {
   # example using mtcars dataset
   fit <- stan_lm(mpg ~ ., data = mtcars, prior = R2(location = 0.75), 
                  chains = CHAINS, iter = ITER, seed = SEED, refresh = REFRESH)
+  expect_stanreg(fit)
+  
   fit_sigma <- fit$stan_summary["sigma", "mean"]
   lm_sigma <- summary(lm(mpg ~ ., data = mtcars))$sigma
   expect_equal(fit_sigma, lm_sigma, tol = threshold)
@@ -39,6 +43,8 @@ test_that("stan_lm returns expected result for trees example", {
   fit <- stan_lm(log(Volume) ~ log(Girth) + log(Height), data = trees, 
                   prior = R2(location = 0.9, what = "mean"), refresh = REFRESH,
                   chains = CHAINS, iter = ITER, seed = SEED, adapt_delta = 0.999)
+  expect_stanreg(fit)
+  
   fit_sigma <- fit$stan_summary["sigma", "mean"]
   lm_sigma <- summary(lm(log(Volume) ~ log(Girth) + log(Height),data = trees))$sigma
   expect_equal(fit_sigma, lm_sigma, tol = threshold)
@@ -48,10 +54,13 @@ test_that("stan_lm doesn't break with less common priors", {
   # prior = NULL
   expect_output(fit <- stan_lm(mpg ~ -1 + ., data = mtcars, prior = NULL,
                 iter = 10, chains = 1, seed = SEED), regexp = "SAMPLING")
+  expect_stanreg(fit)
+  
   # prior_intercept = normal()
   expect_output(fit <- stan_lm(mpg ~ ., data = mtcars, 
                                prior = R2(0.75), prior_intercept = normal(),
                                iter = 10, chains = 1, seed = SEED), regexp = "SAMPLING")
+  expect_stanreg(fit)
 })
 
 test_that("stan_lm doesn't break with vb algorithms", {
@@ -59,8 +68,11 @@ test_that("stan_lm doesn't break with vb algorithms", {
                                prior = R2(location = 0.75),
                                algorithm = "meanfield", seed = SEED), 
                 regexp = "Automatic Differentiation Variational Inference")
+  expect_stanreg(fit)
+  
   expect_output(fit2 <- update(fit, algorithm = "fullrank"), 
                 regexp = "Automatic Differentiation Variational Inference")
+  expect_stanreg(fit2)
 })
 
 test_that("stan_lm throws error if only intercept", {
@@ -84,6 +96,8 @@ context("stan_aov")
 test_that("stan_aov returns expected result for npk example", {
   fit <- stan_aov(yield ~ block + N*P*K, data = npk, contrasts = "contr.poly",
            prior = R2(0.5), chains = CHAINS, iter = ITER, seed = SEED, refresh = REFRESH)
+  expect_stanreg(fit)
+  
   fit_sigma <- fit$stan_summary["sigma", "mean"]
   lm_sigma <- summary(lm(yield ~ block + N*P*K, data = npk, contrasts = "contr.poly"))$sigma
   expect_equal(fit_sigma, lm_sigma, tol = threshold)
